==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentageVolumeOscillatorIndicatorDescription } from "./PercentageVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentageVolumeOscillatorIndicatorDescriptionMetadata, _super);
    function PercentageVolumeOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (PercentageVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.c(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.g(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.d = function (a) {
        PercentageVolumeOscillatorIndicatorDescriptionMetadata.b(a);
        a.u("PercentageVolumeOscillatorIndicator", function () { return new PercentageVolumeOscillatorIndicatorDescription(); });
        a.t("PercentageVolumeOscillatorIndicator", PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(PercentageVolumeOscillatorIndicatorDescriptionMetadata, 'PercentageVolumeOscillatorIndicatorDescriptionMetadata');
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentageVolumeOscillatorIndicatorDescriptionMetadata;
}(Base));
export { PercentageVolumeOscillatorIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentageVolumeOscillatorIndicatorDescription } from "./PercentageVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentageVolumeOscillatorIndicatorDescriptionMetadata, _super);
    function PercentageVolumeOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (PercentageVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.c(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.d = function (a) {
        PercentageVolumeOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("PercentageVolumeOscillatorIndicator", function () { return new PercentageVolumeOscillatorIndicatorDescription(); });
        a.z("PercentageVolumeOscillatorIndicator", PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(PercentageVolumeOscillatorIndicatorDescriptionMetadata, 'PercentageVolumeOscillatorIndicatorDescriptionMetadata');
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentageVolumeOscillatorIndicatorDescriptionMetadata;
}(Base));
export { PercentageVolumeOscillatorIndicatorDescriptionMetadata };
